@@ -9,11 +9,11 @@ R_len_t translate_row(R_len_t, R_len_t);
 R_len_t translate_col(R_len_t, R_len_t);
 R_len_t attribute_hidden get_ncols(SEXP);
 R_len_t attribute_hidden get_nrows(SEXP);
-double attribute_hidden asNumber(SEXP, const char *);
-const char attribute_hidden * asString(SEXP, const char *);
-R_len_t attribute_hidden asCount(SEXP, const char *);
-R_xlen_t attribute_hidden asLength(SEXP, const char *);
-Rboolean attribute_hidden asFlag(SEXP, const char *);
+double attribute_hidden as_number(SEXP, const char *);
+const char attribute_hidden * as_string(SEXP, const char *);
+R_len_t attribute_hidden as_count(SEXP, const char *);
+R_xlen_t attribute_hidden as_length(SEXP, const char *);
+Rboolean attribute_hidden as_flag(SEXP, const char *);
 
 Rboolean is_class_logical(SEXP x);
 Rboolean is_class_integer(SEXP x);
@@ -34,5 +34,4 @@ Rboolean is_class_null(SEXP x);
 Rboolean is_class_posixct(SEXP x);
 Rboolean is_class_raw(SEXP x);
 
-
 #endif
